@@ -137,12 +137,17 @@ class NumerousApp():
 
         return self.result
 
+
 class DefaultOutputHandler:
     def __init__(self, client: NumerousClient):
         self.output = client.new_writer(buffer_size=0)
-    def write_row(self, row: dict):
+
+    def write_row(self, t: float, row: dict):
         self.output.write_row(row)
 
+    def close(self):
+        self.output.close()
+
 
 def checkpoint(tnow, tlast, interval=60):
     dt=datetime.timedelta(minutes=interval)
@@ -174,7 +179,7 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
         if reset_job is None:
             RESET_JOB = os.getenv('RESET_JOB', 'False') == "True"
         else:
-            RESET_JOB = reset_job        
+            RESET_JOB = reset_job
 
         if numerous_job is None:
             raise KeyError("no simulation job specified")
@@ -190,7 +195,6 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
                           max_restarts=max_restarts, numerous_job=numerous_job, model_folder=model_folder,
                           working_folder=working_folder, reset_job=RESET_JOB)
 
-
         app.terminate = terminate
         app.client.terminate_event = terminate
         app.loop()
@@ -209,6 +213,7 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
             app.client.state.set('_status', -2)
     finally:
         if app and app.client is not None:
+            app.output.close()
             app.client.close()
         if app:
             #Return the result of the app
@@ -217,8 +222,3 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
     return
 
 
-
-
-
-
-
