@@ -52,7 +52,6 @@ class NumerousBaseJob:
         self._details = ""
         # Wrapper to allow specialized instanciation of components
         self.wrapper = None
-        self.output = None
 
     def _post_init(self):  # This is called before _run_job from the app.loop method
         timeout = 120
@@ -75,8 +74,6 @@ class NumerousBaseJob:
         self.system = NumerousSystem(self.app.client, self.app.scenario, self.app.files, self.app.start_time, t_stop,
                                      self.app.model_folder, self, states, t, dt, self.input, wrapper=self.wrapper)
 
-        self.output = self.app.output  # link to app output class
-
     def serialize_states(self, t: float = None) -> Optional[Any]:
         """
         A method called when saving states.
@@ -292,7 +289,7 @@ class NumerousSimulationJob(NumerousBaseJob):
                         if "_index" not in initial_output:
                             initial_output.update({'_index': 0})
 
-                        self.output.write_row(initial_output)
+                        self.app.output.write_row(t, initial_output)
 
                 try:
                     tnew, outputs = self.step(t, self.system.dt)
@@ -315,7 +312,7 @@ class NumerousSimulationJob(NumerousBaseJob):
                 # Advance time
                 t = tnew
                 # save output
-                self.output.write_row(outputs)
+                self.app.output.write_row(t, outputs)
 
                 if time() - last_logged > dt_log:
                     last_logged = time()
